@@ -32,8 +32,8 @@ class WorkspaceRun:
         args, unknown = parser.parse_known_args()
         args_dict = vars(args)
 
-        if not args_dict['args'] == '':
-            self.custom_args = args_dict['args']\
+        if not args_dict['argument'] == '':
+            self.custom_args = args_dict['argument']\
                 .replace('[[:space:]]', " ").replace('[[:equal:]]', '=').replace('[[:hyphen:]]', '--')
 
         self.code_path = args_dict['codePath']
